@@ -49,6 +49,9 @@ fn synchronize_filename(path: &Path) -> Result<PathBuf, WorkflowError> {
         Err(e) if matches!(e, NoteError::MissingFrontMatterField { .. }) => {
             return Err(WorkflowError::MissingFrontMatterField { source: e })
         }
+        Err(e) if matches!(e, NoteError::InvalidFrontMatterYaml { .. }) => {
+            return Err(WorkflowError::InvalidFrontMatterYaml { source: e })
+        }
         Err(e) => return Err(e.into()),
     };
 
@@ -129,6 +132,11 @@ fn create_new_note_or_synchronize_filename(path: &Path) -> Result<PathBuf, Workf
     // First generate a new note (if it does not exist), then parse its front_matter
     // and finally rename the file, if it is not in sync with its front matter.
     if path.is_dir() {
+        // Error if we are supposed to export a directory.
+        if ARGS.export.is_some() {
+            return Err(WorkflowError::ExportsNeedsNoteFile);
+        };
+
         let (n, new_file_path) = if STDIN.is_empty() && CLIPBOARD.is_empty() {
             // CREATE A NEW NOTE WITH `TMPL_NEW_CONTENT` TEMPLATE
             log::trace!("Applying templates `[tmpl] new_content` and `[tmpl] new_filename`.");
@@ -213,6 +221,11 @@ fn create_new_note_or_synchronize_filename(path: &Path) -> Result<PathBuf, Workf
             // Check if in sync with its filename:
             Ok(synchronize_filename(path)?)
         } else {
+            // Error if we are supposed to export an unknown file type.
+            if ARGS.export.is_some() {
+                return Err(WorkflowError::ExportsNeedsNoteFile);
+            };
+
             // ANNOTATE FILE: CREATE NEW NOTE WITH TMPL_ANNOTATE_CONTENT TEMPLATE
             // `path` points to a foreign file type that will be annotated.
             log::trace!(
@@ -258,10 +271,6 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
         env::current_dir()?
     };
 
-    if ARGS.export.is_some() && !path.is_file() {
-        return Err(WorkflowError::ExportsNeedsNoteFile);
-    };
-
     // Depending on this we might not show the viewer later or
     // log an error as WARN level instead of ERROR level.
     let mut missing_header;
@@ -276,16 +285,19 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
             }
         }
         Err(e) => {
-            if path.is_file()
-                && !matches!(e, WorkflowError::Io { .. })
-                && !matches!(e, WorkflowError::File { .. })
-                && !matches!(e, WorkflowError::Template { .. })
+            if (matches!(e, WorkflowError::InvalidFrontMatterYaml { .. })
+                || matches!(e, WorkflowError::MissingFrontMatter { .. })
+                || matches!(e, WorkflowError::MissingFrontMatterField { .. }))
                 && !ARGS.batch
+                && ARGS.export.is_none()
             {
+                // Continue the workflow.
+
                 missing_header = matches!(e, WorkflowError::MissingFrontMatter { .. })
                     || matches!(e, WorkflowError::MissingFrontMatterField { .. });
 
                 if *LAUNCH_VIEWER || missing_header {
+                    // Inform user when `--debug warn`, then continue workflow.
                     log::warn!(
                         "{}\n\
                         \n\
@@ -294,6 +306,7 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
                         e,
                     );
                 } else {
+                    // Inform user, then continue workflow.
                     log::error!(
                         "{}\n\
                         \n\
@@ -302,7 +315,6 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
                     );
                 };
             } else {
-                // If `path` points to a directory, no viewer and no editor can open.
                 // This is a fatal error, so we quit.
                 return Err(e);
             }
